@@ -40,7 +40,19 @@
  ***********************************************************************/
 
 #include "calculations.h"
+#include "fields.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <complex.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+#define CCJ   (0.0 - I * 0.01666666667)
 
 /*-------------------------------------------------------------------*/
 
@@ -598,8 +610,8 @@ void intrp( double x, double y, complex double *f1,
   {
     first_call = FALSE;
     size_t mreq = 3*sizeof(int);
-    mem_alloc( (void **)&nda,  mreq, _("in calculations.c"));
-    mem_alloc( (void **)&ndpa, mreq, _("in calculations.c"));
+    Mem_Alloc( (void **)&nda,  mreq, _("in calculations.c"));
+    Mem_Alloc( (void **)&ndpa, mreq, _("in calculations.c"));
     nda[0] = 11; nda[1] = 17; nda[2] = 9;
     ndpa[0] = 110; ndpa[1] = 85; ndpa[2] = 72;
   }
@@ -1223,11 +1235,11 @@ trio( int j )
       {
         segj.maxcon = segj.jsno +1;
         size_t mreq = (size_t)segj.maxcon * sizeof(int);
-        mem_realloc( (void **)&segj.jco, mreq, _("in calculations.c") );
+        Mem_Realloc( (void **)&segj.jco, mreq, _("in calculations.c") );
         mreq = (size_t)segj.maxcon * sizeof(double);
-        mem_realloc( (void **) &segj.ax, mreq, _("in calculations.c") );
-        mem_realloc( (void **) &segj.bx, mreq, _("in calculations.c") );
-        mem_realloc( (void **) &segj.cx, mreq, _("in calculations.c") );
+        Mem_Realloc( (void **) &segj.ax, mreq, _("in calculations.c") );
+        Mem_Realloc( (void **) &segj.bx, mreq, _("in calculations.c") );
+        Mem_Realloc( (void **) &segj.cx, mreq, _("in calculations.c") );
       }
 
       sbf( j, j, &segj.ax[jsnox], &segj.bx[jsnox], &segj.cx[jsnox]);
@@ -1255,11 +1267,11 @@ trio( int j )
       {
         segj.maxcon = segj.jsno +1;
         size_t mreq = (size_t)segj.maxcon * sizeof(int);
-        mem_realloc( (void **)&segj.jco, mreq, _("in calculations.c") );
+        Mem_Realloc( (void **)&segj.jco, mreq, _("in calculations.c") );
         mreq = (size_t)segj.maxcon * sizeof(double);
-        mem_realloc( (void **) &segj.ax, mreq, _("in calculations.c") );
-        mem_realloc( (void **) &segj.bx, mreq, _("in calculations.c") );
-        mem_realloc( (void **) &segj.cx, mreq, _("in calculations.c") );
+        Mem_Realloc( (void **) &segj.ax, mreq, _("in calculations.c") );
+        Mem_Realloc( (void **) &segj.bx, mreq, _("in calculations.c") );
+        Mem_Realloc( (void **) &segj.cx, mreq, _("in calculations.c") );
       }
 
       sbf( jcox, j, &segj.ax[jsnox], &segj.bx[jsnox], &segj.cx[jsnox]);
@@ -1302,11 +1314,11 @@ trio( int j )
   {
     segj.maxcon = segj.jsno +1;
     size_t mreq = (size_t)segj.maxcon * sizeof(int);
-    mem_realloc( (void **)&segj.jco, mreq, _("in calculations.c") );
+    Mem_Realloc( (void **)&segj.jco, mreq, _("in calculations.c") );
     mreq = (size_t)segj.maxcon * sizeof(double);
-    mem_realloc( (void **) &segj.ax, mreq, _("in calculations.c") );
-    mem_realloc( (void **) &segj.bx, mreq, _("in calculations.c") );
-    mem_realloc( (void **) &segj.cx, mreq, _("in calculations.c") );
+    Mem_Realloc( (void **) &segj.ax, mreq, _("in calculations.c") );
+    Mem_Realloc( (void **) &segj.bx, mreq, _("in calculations.c") );
+    Mem_Realloc( (void **) &segj.cx, mreq, _("in calculations.c") );
   }
 
   sbf( j, j, &segj.ax[jsnox], &segj.bx[jsnox], &segj.cx[jsnox]);
