@@ -17,15 +17,23 @@
 #ifndef DRAW_RADIATION_H
 #define DRAW_RADIATION_H        1
 
-#include "common.h"
+#include "shared.h"
+#include <gtk/gtk.h>
 
-/* Point in 3d xyz axes */
-typedef struct
-{
-  double
-    x, y, z, r;
-
-} point_3d_t;
+/* draw_radiation.c */
+void Draw_Radiation(cairo_t *cr);
+gboolean Animate_Near_Field(gpointer udata);
+double Polarization_Factor(int pol_type, int fstep, int idx);
+void Set_Polarization(int pol);
+void Set_Gain_Style(int gs);
+void New_Radiation_Projection_Angle(void);
+gboolean Redo_Radiation_Pattern(gpointer udata);
+double Viewer_Gain(projection_parameters_t proj_parameters, int fstep);
+void Rdpattern_Window_Killed(void);
+void Set_Window_Labels(void);
+void Alloc_Rdpattern_Buffers(int nfrq, int nth, int nph);
+void Alloc_Nearfield_Buffers(int n1, int n2, int n3);
+void Free_Draw_Buffers(void);
 
 #endif
 
