@@ -40,13 +40,42 @@
  **********************************************************************/
 
 #include "fields.h"
+#include "calculations.h"
+#include "draw_radiation.h"
+#include "ground.h"
+#include "somnec.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <complex.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+#define TPJ     (0.0 + I * M_2PI)
+#define PI8     25.13274123
+#define FPI     12.56637062
+#define CONST2  4.771341188
 
 /* common  /tmi/ */
-static tmi_t tmi;
+static struct
+{
+  int ij;
+  double
+    zpk,
+    rkb2;
+} tmi;
 
 /*common  /tmh/ */
-static tmh_t tmh;
+static struct
+{
+  double
+    zpka,
+    rhks;
+} tmh;
 
 /*-------------------------------------------------------------------*/
 
@@ -271,7 +300,7 @@ efld( double xi, double yi,
   static complex double *egnd = NULL;
 
   size_t mreq = 9 * sizeof(complex double);
-  mem_alloc( (void **)&egnd, mreq, "in fields.c");
+  Mem_Alloc( (void **)&egnd, mreq, "in fields.c");
 
   xij= xi- dataj.xj;
   yij= yi- dataj.yj;
