@@ -17,32 +17,17 @@
 #ifndef FIELDS_H
 #define FIELDS_H        1
 
-#include "common.h"
-
-#define TPJ     (0.0+I*M_2PI)
-#define PI8     25.13274123
-#define FPI     12.56637062
-#define CONST2  4.771341188
-
-/* common  /tmi/ */
-typedef struct
-{
-  int ij;
-
-  double
-    zpk,
-    rkb2;
-
-} tmi_t;
-
-/*common  /tmh/ */
-typedef struct
-{
-  double
-    zpka,
-    rhks;
-
-} tmh_t;
+/* fields.c */
+void efld(double xi, double yi, double zi, double ai, int ij);
+void gf(double zk, double *co, double *si);
+void gh(double zk, double *hr, double *hi);
+void gwave(_Complex double *erv, _Complex double *ezv, _Complex double *erh, _Complex double *ezh, _Complex double *eph);
+void gx(double zz, double rh, double xk, _Complex double *gz, _Complex double *gzp);
+void hintg(double xi, double yi, double zi);
+void hsfld(double xi, double yi, double zi, double ai);
+void nfpat(int nfeh);
+void pcint(double xi, double yi, double zi, double cabi, double sabi, double salpi, _Complex double *e);
+void unere(double xob, double yob, double zob);
 
 #endif
 
