@@ -15,7 +15,25 @@
  */
 
 #include "fork.h"
+#include "input.h"
+#include "main.h"
 #include "shared.h"
+#include "utils.h"
+#include "xnec2c.h"
+
+#include <complex.h>
+#include <gtk/gtk.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+/* Near Field select flags */
+#define E_HFIELD    0x01
+#define SNAPSHOT    0x02
+#define EFIELD      0x04
+#define HFIELD      0x08
 
 /*-----------------------------------------------------------------------*/
 
@@ -72,7 +90,7 @@ Fork_Command( const char *cdstr )
   static int
 write_exact( int fd, char *buf, int size )
 {
-  int len    = 0;
+  int len;
   int offset = 0;
 
   do
@@ -105,7 +123,7 @@ write_exact( int fd, char *buf, int size )
   static int
 read_exact( int fd, char *buf, int size )
 {
-  int len    = 0;
+  int len;
   int offset = 0;
 
   do
@@ -262,7 +280,7 @@ Pass_Freq_Data( void )
     Write_Pipe( num_child_procs, "noeh", 4, TRUE );
 
   /* Allocate data buffers */
-  mem_alloc( (void **)&buff, buff_size, "in fork.c" );
+  Mem_Alloc( (void **)&buff, buff_size, "in fork.c" );
 
   /* Clear buffer index in this function */
   Mem_Copy( buff, buff, 0, WRITE );
@@ -379,7 +397,7 @@ Pass_Freq_Data( void )
   /* Pass data accumulated in buffer if child */
   Write_Pipe( num_child_procs, buff, (ssize_t)buff_size, TRUE );
 
-  free_ptr( (void **)&buff );
+  Mem_Free( (void **)&buff );
 
 } /* Pass_Freq_Data() */
 
@@ -625,7 +643,7 @@ Get_Freq_Data( int idx, int fstep )
   }
 
   /* Allocate data buffer */
-  mem_alloc( (void **)&buff, buff_size, "in fork.c" );
+  Mem_Alloc( (void **)&buff, buff_size, "in fork.c" );
 
   /* Clear buffer index in Mem_Copy()Mem_Copy( */
   Mem_Copy( NULL, NULL, 0, READ );
@@ -633,7 +651,7 @@ Get_Freq_Data( int idx, int fstep )
   /* Get data accumulated in buffer if child */
   if( PRead_Pipe( idx, buff, (ssize_t)buff_size, TRUE ) == -1 )
   {
-      free_ptr((void **)&buff);
+      Mem_Free((void **)&buff);
       return;
   }
 
@@ -742,7 +760,7 @@ Get_Freq_Data( int idx, int fstep )
 
   } /*if( isFlagSet(DRAW_EHFIELD) ) */
 
-  free_ptr( (void **)&buff );
+  Mem_Free( (void **)&buff );
 
 } /* Get_Freq_Data() */
 
