@@ -17,12 +17,12 @@
 #ifndef FORK_H
 #define FORK_H      1
 
-#include "common.h"
+#include <gtk/gtk.h>
 
 /* Parent/child commands
  * Note: these must be 7 bytes long.  This is hard-coded!
  */
-#define FORK_CMNDS { "inpfile", "frqdata", "nearehf" }
+#define FORK_CMNDS { "inpfile", "frqdata", "nearehf", "mathlib" }
 
 /* Indices for parent/child commands */
 enum P2CH_COMND
@@ -30,13 +30,13 @@ enum P2CH_COMND
   INFILE = 0,
   FRQDATA,
   EHFIELD,
+  MATHLIB,
   NUM_FKCMNDS
 };
 
-/* Near Field select flags */
-#define E_HFIELD    0x01
-#define SNAPSHOT    0x02
-#define EFIELD      0x04
-#define HFIELD      0x08
+/* fork.c */
+void Child_Process(int num_child);
+ssize_t Write_Pipe(int idx, char *str, ssize_t len, gboolean err);
+void Get_Freq_Data(int idx, int fstep);
 
 #endif
