@@ -40,7 +40,13 @@
  ***********************************************************************/
 
 #include "geometry.h"
+#include "draw_structure.h"
+#include "main.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <gtk/gtk.h>
+#include <math.h>
 
 /*-------------------------------------------------------------------*/
 
@@ -73,17 +79,17 @@ arc( int itg, int ns, double rada,
 
     /* Reallocate tags buffer */
     mreq = (size_t)(data.n + data.m) * sizeof(int);
-    mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
     /* Reallocate wire buffers */
     mreq = (size_t)data.n * sizeof(double);
-    mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.x1, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.y1, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.z1, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.x2, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.y2, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.z2, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
     ang= ang1* TORAD;
     dang=( ang2- ang1)* TORAD/ ns;
@@ -136,21 +142,21 @@ subph( int nx, int ny )
   else data.m += 4;
 
   mreq = (size_t)data.m * sizeof(double);
-  mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.px,  mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.py,  mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.psalp, mreq, "in geometry.c" );
   if( !CHILD )
   {
     mreq = (size_t)(data.n + 2 * data.m) * sizeof(Segment_t);
-    mem_realloc( (void **)&structure_segs, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&structure_segs, mreq, "in geometry.c" );
   }
 
   /* Shift patches to make room for new ones */
@@ -280,8 +286,8 @@ conect( int ignd )
   {
     /* Allocate memory to connections */
     mreq = (size_t)(data.n + data.m) * sizeof(int);
-    mem_realloc( (void **)&data.icon1, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.icon2, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.icon1, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.icon2, mreq, "in geometry.c" );
 
     for( i = 0; i < data.n; i++ )
     {
@@ -479,7 +485,7 @@ conect( int ignd )
 
   /* Allocate to connection buffers */
   mreq = (size_t)segj.maxcon * sizeof(int);
-  mem_realloc( (void **)&segj.jco, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&segj.jco, mreq, "in geometry.c" );
 
   /* Adjust connected segment ends to exactly coincide.
    * Also find old seg. connecting to new segment */
@@ -524,7 +530,7 @@ conect( int ignd )
           {
             segj.maxcon = ic+1;
             mreq = (size_t)segj.maxcon * sizeof(int);
-            mem_realloc( (void **)&segj.jco, mreq, "in geometry.c" );
+            Mem_Realloc( (void **)&segj.jco, mreq, "in geometry.c" );
           }
           segj.jco[ic-1]= ix* jend;
 
@@ -606,9 +612,9 @@ conect( int ignd )
   } /* for( j = 0; j < data.n; j++ ) */
 
   mreq = (size_t)segj.maxcon * sizeof(double);
-  mem_realloc( (void **)&segj.ax, mreq, "in geometry.c" );
-  mem_realloc( (void **)&segj.bx, mreq, "in geometry.c" );
-  mem_realloc( (void **)&segj.cx, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&segj.ax, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&segj.bx, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&segj.cx, mreq, "in geometry.c" );
 
   return( TRUE );
 }
@@ -645,17 +651,17 @@ helix(
 
   /* Reallocate tags buffer */
   mreq = (size_t)data.n * sizeof(int);
-  mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
   /* Reallocate wire buffers */
   mreq = (size_t)data.n * sizeof(double);
-  mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.x1, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.y1, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.z1, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.x2, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.y2, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.z2, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
   /* For a proper helix */
   if( (hl != 0.0) && (tsp != 0.0) )
@@ -827,17 +833,17 @@ move( double rox, double roy,
       k= data.n;
       /* Reallocate tags buffer */
       mreq = (size_t)(data.n + data.m + (data.n + 1 - i1) * nrpt) * sizeof(int);
-      mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
       /* Reallocate wire buffers */
       mreq = (size_t)(data.n + (data.n + 1 - i1) * nrpt) * sizeof(double);
-      mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.x1, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.y1, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.z1, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.x2, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.y2, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.z2, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.bi, mreq, "in geometry.c" );
     }
 
     for( ir = 0; ir < nrp; ir++ )
@@ -881,17 +887,17 @@ move( double rox, double roy,
 
     /* Reallocate patch buffers */
     mreq = (size_t)(data.m * (nrpt + 1)) * sizeof(double);
-    mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.px,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.py,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
     for( ii = 0; ii < nrp; ii++ )
     {
@@ -966,17 +972,17 @@ patch(
 
   /* Reallocate patch buffers */
   mreq = (size_t)data.m * sizeof(double);
-  mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t2y, mreq, "in geometry.c");
-  mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.px,  mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.py,  mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t2y, mreq, "in geometry.c");
+  Mem_Realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
   if( nx > 0) ntp=2;
   else ntp= ny;
@@ -1105,17 +1111,17 @@ patch(
     data.m += nx*ny-1;
     /* Reallocate patch buffers */
     mreq = (size_t)data.m * sizeof(double);
-    mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.px,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.py,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
     xn2= data.px[mi]- s1x- s2x;
     yn2= data.py[mi]- s1y- s2y;
@@ -1191,17 +1197,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
       {
         /* Reallocate tags buffer */
         mreq = (size_t)(2 * data.n + data.m) * sizeof(int);
-        mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
         /* Reallocate wire buffers */
         mreq = (size_t)(2 * data.n) * sizeof(double);
-        mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.x1, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.y1, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.z1, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.x2, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.y2, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.z2, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
         for( i = 0; i < data.n; i++ )
         {
@@ -1245,17 +1251,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
       {
         /* Reallocate patch buffers */
         mreq = (size_t)(2 * data.m) * sizeof(double);
-        mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.px,  mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.py,  mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
         for( i = 0; i < data.m; i++ )
         {
@@ -1296,16 +1302,16 @@ reflc( int ix, int iy, int iz, int iti, int nop )
       {
         /* Reallocate tags buffer */
         mreq = (size_t)(2 * data.n) * sizeof(int);
-        mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.itag, mreq, "in geometry.c" );
         /* Reallocate wire buffers */
         mreq = (size_t)(2 * data.n) * sizeof(double);
-        mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.x1, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.y1, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.z1, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.x2, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.y2, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.z2, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
         for( i = 0; i < data.n; i++ )
         {
@@ -1349,17 +1355,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
       {
         /* Reallocate patch buffers */
         mreq = (size_t)(2 * data.m) * sizeof(double);
-        mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
-        mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.px,  mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.py,  mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+        Mem_Realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
         for( i = 0; i < data.m; i++ )
         {
@@ -1401,17 +1407,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
     {
       /* Reallocate tags buffer */
       mreq = (size_t)(2 * data.n) * sizeof(int);
-      mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
       /* Reallocate wire buffers */
       mreq = (size_t)(2 * data.n) * sizeof(double);
-      mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
-      mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.x1, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.y1, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.z1, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.x2, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.y2, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.z2, mreq, "in geometry.c" );
+      Mem_Realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
       for( i = 0; i < data.n; i++ )
       {
@@ -1453,17 +1459,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 
     /* Reallocate patch buffers */
     mreq = (size_t)(2 * data.m) * sizeof(double);
-    mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.px,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.py,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
     for( i = 0; i < data.m; i++ )
     {
@@ -1510,17 +1516,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 
     /* Reallocate tags buffer */
     mreq = (size_t)data.n * sizeof(int);
-    mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
     /* Reallocate wire buffers */
     mreq = (size_t)data.n * sizeof(double);
-    mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
-    mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.x1, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.y1, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.z1, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.x2, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.y2, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.z2, mreq, "in geometry.c" );
+    Mem_Realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
     for( i = nx; i < data.n; i++ )
     {
@@ -1553,17 +1559,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 
   /* Reallocate patch buffers */
   mreq = (size_t)data.m * sizeof(double);
-  mem_realloc( (void **)&data.px,  mreq, "in geometry.c"  );
-  mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.px,  mreq, "in geometry.c"  );
+  Mem_Realloc( (void **)&data.py,  mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
   for( i = nx; i < data.m; i++ )
   {
@@ -1605,7 +1611,17 @@ wire( double xw1, double yw1, double zw1,
   double xd, yd, zd, delz, rd, fns, radz;
   double xs1, ys1, zs1, xs2, ys2, zs2;
 
-  if( ns < 1) return;
+
+  // This is to silence warnings from Coverity scanner
+  if( (ns < 1) || (ns > 1000000000) )
+  {
+    fprintf( stderr,
+        _("xnec2c: Tag_Seg_Error(): geometry data card error - "
+          "number of segments out of bounds\n") );
+    Stop( _("Tag_Seg_Error(): Geometry data error\n"
+          "Number of segments out of bounds"), ERR_OK );
+    return;
+  }
 
   ist= data.n;
   data.n= data.n+ ns;
@@ -1615,17 +1631,17 @@ wire( double xw1, double yw1, double zw1,
 
   /* Reallocate tags buffer */
   mreq = (size_t)data.n * sizeof(int);
-  mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
   /* Reallocate wire buffers */
   mreq = (size_t)data.n * sizeof(double);
-  mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
-  mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.x1, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.y1, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.z1, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.x2, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.y2, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.z2, mreq, "in geometry.c" );
+  Mem_Realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
   xd= xw2- xw1;
   yd= yw2- yw1;
