@@ -15,7 +15,13 @@
  */
 
 #include "gnuplot.h"
+#include "draw_radiation.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <math.h>
+#include <ctype.h>
+#include <gtk/gtk.h>
 
 /*-----------------------------------------------------------------------*/
 
@@ -181,14 +187,16 @@ Save_FreqPlots_Gnuplot_Data( char *filename )
   /* Plot z-real and z-imag */
   if( isFlagSet(PLOT_ZREAL_ZIMAG) )
   {
-    fprintf( fp, _("# Z real & Z imaginary vs Frequency\n") );
     idx = 0;
+    fprintf( fp, _("# Z real & Z imaginary vs Frequency\n") );
     for( int step = 0; step <= calc_data.last_step; step++ )
+    {
       fprintf( fp, "%13.6E %10.3E %10.3E\n",
           save.freq[idx], impedance_data.zreal[idx], impedance_data.zimag[idx] );
+      idx++;
+    }
+ 
     fprintf( fp, "\n\n" );
-
-    idx++;
   } /* if( isFlagSet(PLOT_ZREAL_ZIMAG) ) */
 
   /* Plot z-magn and z-phase */
@@ -197,9 +205,11 @@ Save_FreqPlots_Gnuplot_Data( char *filename )
     idx = 0;
     fprintf( fp, _("# Z magnitude & Z phase vs Frequency\n") );
     for( int step = 0; step <= calc_data.last_step; step++ )
+    {
       fprintf( fp, "%13.6E %10.3E %10.3E\n",
           save.freq[idx], impedance_data.zmagn[idx], impedance_data.zphase[idx] );
-    idx++;
+      idx++;
+    }
   } /* if( isFlagSet(PLOT_ZREAL_ZIMAG) ) */
 
   fclose(fp);
@@ -354,10 +364,10 @@ Save_RadPattern_Gnuplot_Data( char *filename )
       if( !mreq || (mreq != (size_t)npts * sizeof(double)) )
       {
         mreq = (size_t)npts * sizeof( double );
-        mem_realloc( (void **)&pov_x, mreq, "in draw_radiation.c" );
-        mem_realloc( (void **)&pov_y, mreq, "in draw_radiation.c" );
-        mem_realloc( (void **)&pov_z, mreq, "in draw_radiation.c" );
-        mem_realloc( (void **)&pov_r, mreq, "in draw_radiation.c" );
+        Mem_Realloc( (void **)&pov_x, mreq, "in draw_radiation.c" );
+        Mem_Realloc( (void **)&pov_y, mreq, "in draw_radiation.c" );
+        Mem_Realloc( (void **)&pov_z, mreq, "in draw_radiation.c" );
+        Mem_Realloc( (void **)&pov_r, mreq, "in draw_radiation.c" );
       }
 
       /* Calculate Poynting vector and its max and min */
