@@ -15,9 +15,12 @@
  */
 
 #ifndef GNUPLOT_H
-#define GNUPLOT_H       1
+#define GNUPLOT_H   1
 
-#include "common.h"
+/* gnuplot.c */
+void Save_FreqPlots_Gnuplot_Data(char *filename);
+void Save_RadPattern_Gnuplot_Data(char *filename);
+void Save_Struct_Gnuplot_Data(char *filename);
 
 #endif
 
