@@ -17,19 +17,14 @@
 #ifndef MAIN_H
 #define MAIN_H      1
 
-#include "common.h"
-#include "callbacks.h"
-#include "interface.h"
-#include "fork.h"
-#include "nec2_model.h"
-#include <sys/wait.h>
+#include <gtk/gtk.h>
 
-#define OPEN_INPUT_FLAGS \
-  RDPAT_FLAGS       | \
-  FREQ_LOOP_FLAGS   | \
-  PLOT_FREQ_LINE    | \
-  ENABLE_EXCITN     | \
-  INPUT_OPENED
+/* main.c */
+int main(int argc, char *argv[]);
+gboolean Open_Input_File(gpointer arg);
+gboolean isChild(void);
+
+#define CHILD   isChild()
 
 #endif
 
