@@ -15,7 +15,12 @@
  */
 
 #include "nec2_model.h"
+#include "editors.h"
+#include "input.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <gtk/gtk.h>
 
 /*------------------------------------------------------------------------*/
 
