@@ -17,7 +17,16 @@
 #ifndef NETWORK_H
 #define NETWORK_H       1
 
-#include "common.h"
+#include <complex.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+/* network.c */
+void netwk(_Complex double *cmx, int *ip, _Complex double *einc);
+void load(int *ldtyp, int *ldtag, int *ldtagf, int *ldtagt, double *zlr, double *zli, double *zlc);
 
 #endif
 
