@@ -26,7 +26,21 @@
  */
 
 #include "plot_freqdata.h"
+#include "draw.h"
+#include "draw_radiation.h"
+#include "draw_structure.h"
+#include "interface.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <complex.h>
+#include <gtk/gtk.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
 
 /* Graph plot bounding rectangle */
 static GdkRectangle plot_rect;
@@ -72,14 +86,14 @@ Display_Frequency_Data( void )
     /* Display max gain */
     snprintf( txt, 7, "%5.1f", gmax );
     gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
-            freqplots_window_builder, "freqplots_maxgain_entry")), txt );
+            plots_window_builder, "plots_maxgain_entry")), txt );
 
   } /* isFlagSet(ENABLE_RDPAT) */
 
   /* Display frequency */
   snprintf( txt, 11, "%9.3f", (double)calc_data.freq_mhz );
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
-          freqplots_window_builder, "freqplots_fmhz_entry")), txt );
+          plots_window_builder, "plots_fmhz_entry")), txt );
 
   /* Calculate VSWR */
   zrpro2 = (double)creal( netcx.zped ) + calc_data.zo;
@@ -96,17 +110,17 @@ Display_Frequency_Data( void )
   /* Display VSWR */
   snprintf( txt, 7, "%5.1f", vswr );
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
-          freqplots_window_builder, "freqplots_vswr_entry")), txt );
+          plots_window_builder, "plots_vswr_entry")), txt );
 
   /* Display Z real */
   snprintf( txt, 7, "%5.1f", (double)creal( netcx.zped ) );
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
-          freqplots_window_builder, "freqplots_zreal_entry")), txt );
+          plots_window_builder, "plots_zreal_entry")), txt );
 
   /* Display Z imaginary */
   snprintf( txt, 7, "%5.1f", (double)cimag( netcx.zped ) );
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
-          freqplots_window_builder, "freqplots_zimag_entry")), txt );
+          plots_window_builder, "plots_zimag_entry")), txt );
 
 } /* Display_Frequency_Data() */
 
@@ -427,7 +441,7 @@ Plot_Horizontal_Scale(
 
   /* Create a pango layout */
   layout = gtk_widget_create_pango_layout(
-      freqplots_drawingarea, "1234.5" );
+      plots_drawingarea, "1234.5" );
   pango_layout_get_pixel_size( layout, &pl_width, &pl_height);
 
   /* Draw horizontal scale values */
@@ -502,7 +516,7 @@ Plot_Vertical_Scale(
 
   /* Create a pango layout */
   layout = gtk_widget_create_pango_layout(
-      freqplots_drawingarea, "X" );
+      plots_drawingarea, "X" );
   pango_layout_get_pixel_size( layout, &pl_width, &pl_height);
 
   /* Draw vertical scale values */
@@ -543,7 +557,7 @@ Draw_Plotting_Frame(
   /* Draw titles (left scale, center and right scale) */
   cairo_set_source_rgb( cr, MAGENTA );
   layout = gtk_widget_create_pango_layout(
-      freqplots_drawingarea, title[0] );
+      plots_drawingarea, title[0] );
   pango_layout_get_pixel_size( layout, &width0, &height );
   cairo_move_to( cr, rect->x, rect->y );
   pango_cairo_show_layout( cr, layout );
@@ -634,7 +648,7 @@ Draw_Graph(
   rb = bmax - bmin;
 
   /* Calculate points to plot */
-  mem_alloc( (void **) &points, (size_t)calc_data.steps_total * sizeof(GdkPoint),
+  Mem_Alloc( (void **) &points, (size_t)calc_data.steps_total * sizeof(GdkPoint),
       "in Draw_Graph()" );
   if( points == NULL )
   {
@@ -673,7 +687,7 @@ Draw_Graph(
   /* Draw the graph */
   Cairo_Draw_Lines( cr, points, nval );
 
-  free_ptr( (void **)&points );
+  Mem_Free( (void **)&points );
 
 } /* Draw_Graph() */
 
@@ -701,7 +715,7 @@ Plot_Graph2(
     /* Create a pango layout to get scale size */
     PangoLayout *layout;
     layout = gtk_widget_create_pango_layout(
-        freqplots_drawingarea, "000000" );
+        plots_drawingarea, "000000" );
     pango_layout_get_pixel_size( layout,
         &layout_width, &layout_height);
     first_call = FALSE;
@@ -710,14 +724,14 @@ Plot_Graph2(
 
   /* Available height for each graph.
    * (np=number of graphs to be plotted) */
-  plot_height = freqplots_height/nplt;
-  plot_posn   = (freqplots_height * (posn-1))/nplt;
+  plot_height = plots_height/nplt;
+  plot_posn   = (plots_height * (posn-1))/nplt;
 
   /* Plot box rectangle */
   Set_Rectangle(
       &plot_rect,
       layout_width+4, plot_posn+2,
-      freqplots_width-8 - 2*layout_width,
+      plots_width-8 - 2*layout_width,
       plot_height-8 - 2*layout_height );
 
   /*** Draw horizontal (freq) scale ***/
@@ -766,7 +780,7 @@ Plot_Graph2(
   Plot_Vertical_Scale(
       cr,
       CYAN,
-      freqplots_width-2 - layout_width, plot_posn+2,
+      plots_width-2 - layout_width, plot_posn+2,
       plot_rect.height,
       max_fb, min_fb, nval_ab );
 
@@ -829,7 +843,7 @@ Plot_Graph_Smith(
   if( first_call )
   {
     /* Create a pango layout to get scale size */
-    layout = gtk_widget_create_pango_layout( freqplots_drawingarea, "000000" );
+    layout = gtk_widget_create_pango_layout( plots_drawingarea, "000000" );
     pango_layout_get_pixel_size( layout, &layout_width, &layout_height);
     first_call = FALSE;
     g_object_unref( layout );
@@ -837,18 +851,18 @@ Plot_Graph_Smith(
 
   /* Available height for each graph.
    * (np=number of graphs to be plotted) */
-  plot_height = freqplots_height / nplt;
-  plot_posn   = ( freqplots_height * (posn - 1) ) / nplt;
+  plot_height = plots_height / nplt;
+  plot_posn   = ( plots_height * (posn - 1) ) / nplt;
 
   /* Plot box rectangle */
   Set_Rectangle( &plot_rect,
       layout_width + 4, plot_posn + 2,
-      freqplots_width - 8 - 2 * layout_width,
+      plots_width - 8 - 2 * layout_width,
       plot_height - 8 - 2 * layout_height );
 
 
   cairo_set_source_rgb( cr, YELLOW );
-  layout = gtk_widget_create_pango_layout( freqplots_drawingarea, _("Smith Chart") );
+  layout = gtk_widget_create_pango_layout( plots_drawingarea, _("Smith Chart") );
   pango_layout_get_pixel_size( layout, &width1, &height );
   xpw = plot_rect.x + ( plot_rect.width - width1 ) / 2;
   cairo_move_to( cr, xpw, plot_rect.y );
@@ -884,7 +898,7 @@ Plot_Graph_Smith(
   cairo_set_source_rgb( cr, MAGENTA );
 
   /* Calculate points to plot */
-  mem_alloc( (void **)&points, (size_t)calc_data.steps_total * sizeof(GdkPoint),
+  Mem_Alloc( (void **)&points, (size_t)calc_data.steps_total * sizeof(GdkPoint),
       "in Draw_Graph()" );
 
   if( points == NULL )
@@ -909,7 +923,7 @@ Plot_Graph_Smith(
 
   /* Draw the graph */
   Cairo_Draw_Lines( cr, points, nc );
-  free_ptr( (void **)&points );
+  Mem_Free( (void **)&points );
 
   /* Draw a vertical line to show current freq if it was
    * changed by a user click on the plots drawingarea */
@@ -949,7 +963,7 @@ Plot_Graph(
     /* Create a pango layout to get scale size */
     PangoLayout *layout;
     layout = gtk_widget_create_pango_layout(
-        freqplots_drawingarea, "000000" );
+        plots_drawingarea, "000000" );
     pango_layout_get_pixel_size(
         layout, &layout_width, &layout_height);
     first_call = FALSE;
@@ -958,14 +972,14 @@ Plot_Graph(
 
   /* Available height for each graph.
    * (np=number of graphs to be plotted) */
-  plot_height = freqplots_height/nplt;
-  plot_posn   = (freqplots_height * (posn-1))/nplt;
+  plot_height = plots_height/nplt;
+  plot_posn   = (plots_height * (posn-1))/nplt;
 
   /* Plot box rectangle */
   Set_Rectangle(
       &plot_rect,
       layout_width + 4, plot_posn+2,
-      freqplots_width-8 - 2*layout_width,
+      plots_width-8 - 2*layout_width,
       plot_height-8 - 2*layout_height );
 
   /*** Draw horizontal (freq) scale ***/
@@ -1026,7 +1040,7 @@ Plot_Frequency_Data( cairo_t *cr )
 {
   /* Abort plotting if main window is to be closed
    * or when plots drawing area not available */
-  if( isFlagSet(MAIN_QUIT) ||
+  if( //isFlagSet(MAIN_QUIT) ||
       isFlagClear(PLOT_ENABLED) ||
       isFlagClear(ENABLE_EXCITN) )
     return;
@@ -1055,8 +1069,8 @@ Plot_Frequency_Data( cairo_t *cr )
   cairo_set_source_rgb( cr, BLACK );
   cairo_rectangle(
       cr, 0.0, 0.0,
-      (double)freqplots_width,
-      (double)freqplots_height );
+      (double)plots_width,
+      (double)plots_height );
   cairo_fill( cr );
 
   /* Abort if plotting is not possible FIXME */
@@ -1079,7 +1093,7 @@ Plot_Frequency_Data( cairo_t *cr )
     max_fscale = (double)save.freq[calc_data.freq_step];
   else
     max_fscale = (double)save.freq[calc_data.last_step];
-  nval_fscale = freqplots_width / 75;
+  nval_fscale = plots_width / 75;
   Fit_to_Scale( &max_fscale, &min_fscale, &nval_fscale );
 
   /* Graph position */
@@ -1096,12 +1110,12 @@ Plot_Frequency_Data( cairo_t *cr )
 
     /* Allocate max gmax and directions */
     size_t mreq = (size_t)fstep * sizeof(double);
-    mem_realloc( (void **)&gmax,     mreq, "in plot_freqdata.c" );
-    mem_realloc( (void **)&gdir_tht, mreq, "in plot_freqdata.c" );
-    mem_realloc( (void **)&gdir_phi, mreq, "in plot_freqdata.c" );
-    mem_realloc( (void **)&fbratio,  mreq, "in plot_freqdata.c" );
+    Mem_Realloc( (void **)&gmax,     mreq, "in plot_freqdata.c" );
+    Mem_Realloc( (void **)&gdir_tht, mreq, "in plot_freqdata.c" );
+    Mem_Realloc( (void **)&gdir_phi, mreq, "in plot_freqdata.c" );
+    Mem_Realloc( (void **)&fbratio,  mreq, "in plot_freqdata.c" );
     if( isFlagSet(PLOT_NETGAIN) )
-      mem_realloc( (void **)&netgain, mreq, "in plot_freqdata.c" );
+      Mem_Realloc( (void **)&netgain, mreq, "in plot_freqdata.c" );
 
     /* Find max gain and direction, F/B ratio */
     no_fbr = FALSE;
@@ -1237,7 +1251,7 @@ Plot_Frequency_Data( cairo_t *cr )
 
     /* Allocate viewer gain buffer */
     size_t mreq = (size_t)fstep * sizeof(double);
-    mem_realloc( (void **)&vgain, mreq, "in plot_freqdata.c" );
+    Mem_Realloc( (void **)&vgain, mreq, "in plot_freqdata.c" );
 
     /* Calcs are done for all freq steps */
     for( idx = 0; idx < fstep; idx++ )
@@ -1247,7 +1261,7 @@ Plot_Frequency_Data( cairo_t *cr )
     if( isFlagSet(PLOT_NETGAIN) )
     {
       mreq = (size_t)fstep * sizeof(double);
-      mem_realloc( (void **)&netgain, mreq, "in plot_freqdata.c" );
+      Mem_Realloc( (void **)&netgain, mreq, "in plot_freqdata.c" );
 
       Zo = calc_data.zo;
       for( idx = 0; idx < fstep; idx++ )
@@ -1284,7 +1298,7 @@ Plot_Frequency_Data( cairo_t *cr )
     titles[1] = _("VSWR vs Frequency");
 
     /* Calculate VSWR */
-    mem_alloc( (void **) &vswr, (size_t)calc_data.steps_total * sizeof(double),
+    Mem_Alloc( (void **) &vswr, (size_t)calc_data.steps_total * sizeof(double),
         "in Plot_Frequency_Data()" );
     if( vswr == NULL )
     {
@@ -1312,7 +1326,7 @@ Plot_Frequency_Data( cairo_t *cr )
       Plot_Graph( cr, vswr, save.freq, fstep,
           titles, calc_data.ngraph, ++posn );
 
-    free_ptr( (void **)&vswr );
+    Mem_Free( (void **)&vswr );
   } /* if( isFlagSet(PLOT_VSWR) ) */
 
   /* Plot z-real and z-imag */
@@ -1369,20 +1383,20 @@ Plot_Frequency_Data( cairo_t *cr )
   void
 Plots_Window_Killed( void )
 {
-  rc_config.freqplots_width  = 0;
-  rc_config.freqplots_height = 0;
+  rc_config.plots_width  = 0;
+  rc_config.plots_height = 0;
 
   if( isFlagSet(PLOT_ENABLED) )
   {
     ClearFlag( PLOT_FLAGS );
-    freqplots_drawingarea = NULL;
-    g_object_unref( freqplots_window_builder );
-    freqplots_window_builder = NULL;
+    plots_drawingarea = NULL;
+    g_object_unref( plots_window_builder );
+    plots_window_builder = NULL;
 
     gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(
-          Builder_Get_Object(main_window_builder, "main_freqplots")), FALSE );
+          Builder_Get_Object(main_window_builder, "main_plots")), FALSE );
   }
-  freqplots_window = NULL;
+  plots_window = NULL;
   kill_window = NULL;
 
 } /* Plots_Window_Killed() */
@@ -1412,8 +1426,7 @@ Set_Frequency_On_Click( GdkEventButton *event )
   if( x < 0.0 ) x = 0.0;
   else if( x > w ) x = w;
 
-  /* Set freq corresponding to click 'x', to freq spinbuttons FIXME */
-  idx = calc_data.last_step;
+  /* Set freq corresponding to click 'x', to freq spinbuttons */
   switch( event->button )
   {
     case 1: /* Calculate frequency corresponding to mouse position in plot */
@@ -1430,7 +1443,7 @@ Set_Frequency_On_Click( GdkEventButton *event )
       calc_data.fmhz_save = 0.0;
 
       /* Wait for GTK to complete its tasks */
-      gtk_widget_queue_draw( freqplots_drawingarea );
+      gtk_widget_queue_draw( plots_drawingarea );
       //while( g_main_context_iteration(NULL, FALSE) );
       return;
 
