@@ -17,11 +17,18 @@
 #ifndef PLOT_FREQDATA_H
 #define PLOT_FREQDATA_H     1
 
-#include "common.h"
+#include <cairo.h>
+#include <gtk/gtk.h>
+#include "shared.h"
 
 /* For plotting graphs */
 #define LEFT    1
 #define RIGHT   2
 
+/* plot_freqdata.c */
+void Plot_Frequency_Data(cairo_t *cr);
+void Plots_Window_Killed(void);
+void Set_Frequency_On_Click(GdkEventButton *event);
+
 #endif
 
