@@ -40,15 +40,28 @@
  ***********************************************************************/
 
 #include "radiation.h"
+#include "callback_func.h"
+#include "calculations.h"
+#include "draw_radiation.h"
+#include "fields.h"
 #include "shared.h"
+#include "utils.h"
 
-/* Radiation pattern data */
+#include <complex.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+#define CONST3  (0.0 - I * 29.97922085)
 
 /*-----------------------------------------------------------------------*/
 
 /* calculates the xyz components of the electric */
 /* field due to surface currents */
-static void
+  static void
 fflds( double rox, double roy, double roz,
     complex double *scur, complex double *ex,
     complex double *ey, complex double *ez )
@@ -91,7 +104,7 @@ fflds( double rox, double roy, double roz,
 
 /* ffld calculates the far zone radiated electric fields, */
 /* the factor exp(j*k*r)/(r/lamda) not included */
-static void
+  static void
 ffld( double thet, double phi,
     complex double *eth, complex double *eph )
 {
@@ -395,7 +408,7 @@ ffld( double thet, double phi,
 /*-----------------------------------------------------------------------*/
 
 /* gfld computes the radiated field including ground wave. */
-static void
+  static void
 gfld( double rho, double phi, double rz,
     complex double *eth, complex double *epi,
     complex double *erd, complex double ux, int ksymp )
