@@ -17,9 +17,8 @@
 #ifndef RADIATION_H
 #define RADIATION_H     1
 
-#include "common.h"
-
-#define CONST3  (0.0-I*29.97922085)
+/* radiation.c */
+void rdpat(void);
 
 #endif
 
