@@ -15,14 +15,11 @@
  */
 
 #ifndef RC_CONFIG_H
-#define RC_CONFIG_H 1
+#define RC_CONFIG_H   1
 
-#include "common.h"
-#include "utils.h"
-#include "shared.h"
+#include <gtk/gtk.h>
 #include <sys/stat.h>
-
-#define CONFIG_FILE     ".xnec2c/xnec2c.conf"
+#define CONFIG_FILE   ".xnec2c/xnec2c.conf"
 
 /* Format of rc config file to use in snprintf() */
 #define RC_CONFIG_FORMAT \
@@ -108,4 +105,11 @@
 /* Size of string buffer needed to print config file */
 #define RC_FILE_BUF_SIZE    2048
 
+gboolean Create_Default_Config(void);
+void Set_Window_Geometry(GtkWidget *window, gint x, gint y, gint width, gint height);
+gboolean Read_Config(void);
+void Get_GUI_State(void);
+gboolean Save_Config(void);
+
 #endif
+
