@@ -34,7 +34,40 @@
    status of output files set to 'unknown' */
 
 #include "somnec.h"
+#include "calculations.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <complex.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+#define PTP     .6283185308
+#define PI10    31.41592654
+#define TOSP    1.128379167
+#define SP      1.772453851
+#define ACCS    1.0E-12
+#define GAMMA   .5772156649
+#define C1      -.02457850915
+#define C2      .3674669052
+#define C3      .7978845608
+#define P10     .0703125
+#define P20     .1121520996
+#define Q10     .125
+#define Q20     .0732421875
+#define P11     .1171875
+#define P21     .1441955566
+#define Q11     .375
+#define Q21     .1025390625
+#define POF     .7853981635
+#define MAXH    20
+#define CRIT    1.0E-4
+#define NM      131072
+#define NTS     4
 
 /* common /evlcom/ */
 static int jh;
@@ -76,9 +109,9 @@ bessel( complex double z,
     int i;
 
     size_t mreq = 101 * sizeof(double);
-    mem_alloc( (void **)&m, mreq, "in somnec.c");
-    mem_alloc( (void **)&a1, mreq, "in somnec.c");
-    mem_alloc( (void **)&a2, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&m, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&a1, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&a2, mreq, "in somnec.c");
 
     for( k = 1; k <= 25; k++ )
     {
@@ -188,12 +221,12 @@ hankel( complex double z,
   {
     first_call = FALSE;
     size_t mreq = 101 * sizeof(int);
-    mem_alloc( (void **)&m, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&m, mreq, "in somnec.c");
     mreq = 25 * sizeof(double);
-    mem_alloc( (void **)&a1, mreq, "in somnec.c");
-    mem_alloc( (void **)&a2, mreq, "in somnec.c");
-    mem_alloc( (void **)&a3, mreq, "in somnec.c");
-    mem_alloc( (void **)&a4, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&a1, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&a2, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&a3, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&a4, mreq, "in somnec.c");
   }
 
   /* initialization of constants */
@@ -416,14 +449,14 @@ rom1( int n, complex double *sum, int nx )
   {
     first_call = FALSE;
     size_t mreq = 6 * sizeof(complex double);
-    mem_alloc( (void **)&g1, mreq, "in somnec.c");
-    mem_alloc( (void **)&g2, mreq, "in somnec.c");
-    mem_alloc( (void **)&g3, mreq, "in somnec.c");
-    mem_alloc( (void **)&g4, mreq, "in somnec.c");
-    mem_alloc( (void **)&g5, mreq, "in somnec.c");
-    mem_alloc( (void **)&t01, mreq, "in somnec.c");
-    mem_alloc( (void **)&t10, mreq, "in somnec.c");
-    mem_alloc( (void **)&t20, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&g1, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&g2, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&g3, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&g4, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&g5, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&t01, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&t10, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&t20, mreq, "in somnec.c");
   }
 
   lstep=0;
@@ -595,11 +628,11 @@ gshank( complex double start, complex double dela,
   {
     first_call = FALSE;
     size_t mreq = 6 * 20 * sizeof(complex double);
-    mem_alloc( (void **)&q1, mreq, "in somnec.c");
-    mem_alloc( (void **)&q2, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&q1, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&q2, mreq, "in somnec.c");
     mreq = 6 * sizeof(complex double);
-    mem_alloc( (void **)&ans1, mreq, "in somnec.c");
-    mem_alloc( (void **)&ans2, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ans1, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ans2, mreq, "in somnec.c");
   }
 
   rbk=creal(bk);
@@ -767,8 +800,8 @@ evlua( complex double *erv, complex double *ezv,
   {
     first_call = FALSE;
     size_t mreq = 6 * sizeof(complex double);
-    mem_alloc( (void **)&sum, mreq, "in somnec.c");
-    mem_alloc( (void **)&ans, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&sum, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ans, mreq, "in somnec.c");
   }
 
   del=zph;
@@ -917,21 +950,21 @@ somnec( double epr, double sig, double fmhz )
 
     /* Allocate some buffers */
     size_t mreq = sizeof(complex double) * 11 * 10 * 4;
-    mem_alloc( (void **)&ggrid.ar1, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.ar1, mreq, "in somnec.c");
     mreq = sizeof(complex double) * 17 * 5 * 4;
-    mem_alloc( (void **)&ggrid.ar2, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.ar2, mreq, "in somnec.c");
     mreq = sizeof(complex double) * 9 * 8 * 4;
-    mem_alloc( (void **)&ggrid.ar3, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.ar3, mreq, "in somnec.c");
 
     mreq = sizeof(int) * 3;
-    mem_alloc( (void **)&ggrid.nxa, mreq, "in somnec.c");
-    mem_alloc( (void **)&ggrid.nya, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.nxa, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.nya, mreq, "in somnec.c");
 
     mreq = sizeof(double) * 3;
-    mem_alloc( (void **)&ggrid.dxa, mreq, "in somnec.c");
-    mem_alloc( (void **)&ggrid.dya, mreq, "in somnec.c");
-    mem_alloc( (void **)&ggrid.xsa, mreq, "in somnec.c");
-    mem_alloc( (void **)&ggrid.ysa, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.dxa, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.dya, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.xsa, mreq, "in somnec.c");
+    Mem_Alloc( (void **)&ggrid.ysa, mreq, "in somnec.c");
 
     /* Initialize ground grid parameters for somnec */
     ggrid.nxa[0] = 11;
