@@ -17,8 +17,14 @@
 #ifndef XNEC2C_H
 #define XNEC2C_H        1
 
-#include "common.h"
-#include "fork.h"
+#include <gtk/gtk.h>
+
+/* xnec2c.c */
+void Near_Field_Pattern(void);
+void New_Frequency(void);
+gboolean Start_Frequency_Loop(void);
+void Stop_Frequency_Loop(void);
+void Incident_Field_Loop(void);
 
 #endif
 
